Lookup for raster layers
ras_layersA data frame with 86 rows and 11 variables:
Short name of source
Name of the collection within source
Type of layer. e.g. reflectance, indice, variability, derived
A short name
Method used to summarise if more than one layer was available
Units of layer
value * mult = data on original scale. Essentially irrelvant to use of the layers though
A slightly longer description of the layer than layer
Why is this layer ecologically useful?
A reference for the method used to generate the output
A reference for the method used to generate input layer(s)