'Seasons' functionality removed 2025-09-05. If seasons are needed, left join
the result of prepare_env() to the result of make_seasons()``$seasons.
list. usually from yaml::read_yaml("settings/setup.yaml")
Character. Passed to base_dir argument of
envFunc::name_env_out()
Logical. Create a short description to use as a unique 'name'. Requires columns 'name' and 'func'.
Logical. Filter
rows duplicated by layer and func to the latest start_date.
Named list used to exclude rasters, specifying the column name and levels (used as regex) to exclude (filter) within that column.
Passed to envRaster::name_env_tif
tibble of raster paths and meta data parsed into columns